<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Bidding;
use Yajra\DataTables\Facades\DataTables;

class BiddingController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index(Request $request)
    {
        if ($request->ajax()) {
            // Fetch Bidding data with related GameSession and Game
            $data = Bidding::with(['gameSession.game', 'user'])
                ->select('bidding.*')
                ->orderBy('id', 'desc');

            return DataTables::of($data)
                ->addColumn('action', function ($row) {
                    return '<a href="' . route('biddings.edit', $row->id) . '" class="btn btn-success btn-sm">Edit</a>';
                })->addColumn('user_name', function ($row) {
                    return $row->user ? $row->user->name : 'N/A';
                })
                ->addColumn('game', function ($row) {
                    return $row->gameSession->game->game_name ?? 'N/A';
                })
                ->addColumn('session', function ($row) {
                    return $row->gameSession->id ?? 'N/A';
                })
                ->editColumn('total_amount', function ($row) {
                    return $row->total_amount ?? 0;
                })
                ->rawColumns(['action'])
                ->make(true);
        }
        return view('admin.biddings.index');
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        //
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        $bidding = Bidding::findOrFail($id);
        return view('admin.biddings.show', compact('bidding'));
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        Bidding::destroy($id);
        return redirect()->route('admin.biddings.index');
    }
}
