<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;
use App\Models\User;
use Illuminate\Support\Facades\Hash;


class BrokerController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index(Request $request)
    {
        if ($request->ajax()) {
            $data = User::with('role')->where('role_id', 2)->select('users.*');

            return Datatables::of($data)
                ->addColumn('action', function ($row) {
                    return '<a href="' . route('admin.brokers.edit', $row->id) . '" class="btn btn-success btn-sm">Details</a>
                    <a href="' . route('admin.users.brokers', $row->id) . '" class="btn btn-success btn-sm">Broker Users</a>';
                })
                ->rawColumns(['action'])
                ->make(true);
        }
        return view('admin.brokers.index');
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('admin.brokers.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $request->validate([
            'name' => 'required|max:100',
            'username' => 'required|max:100|unique:users,username',
            'email' => ['required', 'string', 'email:rfc,dns', 'max:100', 'unique:' . User::class],
            'password' => 'required:min:6|max:12',
            'commission' => 'required|numeric',
            'singleamount' => 'required|numeric',
            'jodiamount' => 'required|numeric',
        ]);

        $user = User::create([
            'name' => $request->input('name'),
            'username' => $request->input('username'),
            'email' => $request->input('email'),
            'role_id' => 2,
            'password' => Hash::make($request->input('password')),
            'commission' => $request->input('commission'),
            'singleamount' => $request->input('singleamount'),
            'jodiamount' => $request->input('jodiamount'),
        ]);

        return back()->withInput()->with('success', 'Broker Created Successfully!.');
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $user = User::findOrFail($id);
        return view('admin.brokers.edit', compact('user'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        try {
            $user = User::findOrFail($id);

            $passwordValidation = ($request->has('password') && !empty($request->input('password'))) ? 'required|min:6|max:12' : 'nullable';

            $request->validate([
                'name' => 'required|max:100',
                'email' => ['required', 'string', 'email:rfc,dns', 'max:100', 'unique:users,email,' . $user->id],
                'commission' => 'required|numeric',
                'singleamount' => 'required|numeric',
                'jodiamount' => 'required|numeric',
                'status' => 'required',
            ]);

            $user->update([
                'name' => $request->input('name'),
                'email' => $request->input('email'),
                'commission' => $request->input('commission'),
                'singleamount' => $request->input('singleamount'),
                'jodiamount' => $request->input('jodiamount'),
                'status' => $request->input('status'),
            ]);


            return back()->withInput()->with('success', 'Broker Updated Successfully!.');
        } catch (ValidationException $e) {
            return redirect()->back()->withErrors($e->errors())->withInput();
        }
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        //
    }
}
