<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;
use App\Models\User;
use App\Models\Transaction;
use Illuminate\Support\Facades\Hash;


class UserController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index(Request $request, $broker_id = null)
    {
        if ($request->ajax()) {
            $data = User::with('role')->where('role_id',3)->select('users.*');
            if(!empty($request->input('broker_id'))){
                $data = User::with('role')->where('broker_id',$request->input('broker_id'))->where('role_id',3)->select('users.*');
            }


            return Datatables::of($data)
                ->addColumn('action', function($row) {
                    return '<a href="'.route('admin.users.edit', $row->id).'" class="btn btn-success btn-sm">Details</a>';
                })
                ->rawColumns(['action'])
                ->make(true);
        }

        return view('admin.users.index', compact('broker_id'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        $brokers = User::where('role_id',2)->get();
        return view('admin.users.create', compact('brokers'));
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        try {
            $request->validate([
                'name' => 'required|max:100',
                'username' => 'required|max:100|unique:users,username',
                'email' => ['required', 'string', 'email:rfc,dns', 'max:100', 'unique:'.User::class],
                'broker_id' => 'required',
                'password' => 'required:min:6|max:12',
            ]);

            $user = User::create([
                'name' => $request->input('name'),
                'username' => $request->input('username'),
                'email' => $request->input('email'),
                'role_id' => 3,
                'broker_id' => $request->input('broker_id'),
                'password' => Hash::make($request->input('password')),
            ]);

            return back()->withInput()->with('success', 'Customer Created Successfully!.');
        } catch (ValidationException $e) {
            return redirect()->back()->withErrors($e->errors())->withInput();
        }
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $brokers = User::where('role_id',2)->get();
        $user = User::with('wallet')->findOrFail($id);
        $totalDeposits = Transaction::where('CR_ID', $id)->sum('amount');
        return view('admin.users.edit', compact('user','brokers', 'totalDeposits'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        try {
            $user = User::findOrFail($id);

            $passwordValidation = ($request->has('password') && !empty($request->input('password'))) ? 'required|min:6|max:12' : 'nullable';

            $request->validate([
                'name' => 'required|max:100',
                'username' => 'required|max:100|unique:users,username,'.$user->id,
                'email' => ['required', 'string', 'email:rfc,dns', 'max:100', 'unique:users,email,'.$user->id],
                'broker_id' => 'required',
                'password' => $passwordValidation,
                'status' => 'required',
            ]);

            $user->update([
                'name' => $request->input('name'),
                'username' => $request->input('username'),
                'email' => $request->input('email'),
                'broker_id' => $request->input('broker_id'),
                'password' => ($request->has('password') && !empty($request->input('password'))) ? Hash::make($request->input('password')) : $user->password,
                'status' => $request->input('status'),
            ]);
            return back()->withInput()->with('success', 'User Updated Successfully!.');
        } catch (ValidationException $e) {
            return redirect()->back()->withErrors($e->errors())->withInput();
        }
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        //
    }
}
