<?php

namespace App\Http\Middleware;

use App\Providers\RouteServiceProvider;
use Closure;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Symfony\Component\HttpFoundation\Response;

class RedirectIfAuthenticated
{
    /**
     * Handle an incoming request.
     *
     * @param  \Closure(\Illuminate\Http\Request): (\Symfony\Component\HttpFoundation\Response)  $next
     */
    public function handle(Request $request, Closure $next, string ...$guards): Response
    {
        $guards = empty($guards) ? [null] : $guards;

        foreach ($guards as $guard) {
            if (Auth::guard($guard)->check()) {
                // return redirect(RouteServiceProvider::HOME);
                $user = Auth::guard($guard)->user();
                switch ($user->role->name) {
                    case 'admin':
                        return redirect('/admin/dashboard')->with('error', 'You are not allowed to access this area.');
                    case 'broker':
                        return redirect('/broker/dashboard')->with('error', 'You are not allowed to access this area.');
                    case 'customer':
                        return redirect('/customer/dashboard')->with('error', 'You are not allowed to access this area.');
                    default:
                        return redirect('/')->with('error', 'You are not allowed to access this area.');
                }
            }
        }

        return $next($request);
    }

}
