<?php

use App\Http\Controllers\Admin\Auth\AuthenticatedSessionController;
use App\Http\Controllers\Admin\BiddingController;
use App\Http\Controllers\ProfileController;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\Admin\DashboardController as AdminDashboardController;
use App\Http\Controllers\Admin\UserController;
use App\Http\Controllers\Admin\BrokerController;
use App\Http\Controllers\HomeController;
use App\Http\Controllers\Admin\GameController;
use App\Http\Controllers\Admin\GameSessionController;
use App\Http\Controllers\Admin\TransactionController;
use App\Http\Controllers\Admin\WalletController;
use App\Http\Controllers\CustomerDashboardController;
use App\Http\Controllers\BrokerDashboardController;
use App\Http\Controllers\BidController;
use App\Http\Controllers\WithdrawalRequestController;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "web" middleware group. Make something great!
|
*/

require __DIR__ . '/auth.php';
// Admin routes
Route::middleware(['admin'])->group(function () {
    Route::get('/admin/dashboard', [AdminDashboardController::class, 'index'])->name('admin.dashboard');
    Route::get('/admin/users', [UserController::class, 'index'])->name('admin.users.index');
    Route::get('/admin/users/list/{broker_id}', [UserController::class, 'index'])->name('admin.users.brokers');

    Route::get('/admin/users/create', [UserController::class, 'create'])->name('admin.users.create');
    Route::post('/admin/users/create', [UserController::class, 'store'])->name('admin.users.create');

    Route::get('/admin/users/edit/{id}', [UserController::class, 'edit'])->name('admin.users.edit');
    Route::post('/admin/users/edit/{id}', [UserController::class, 'update'])->name('admin.users.edit');

    Route::get('/admin/users/show', [UserController::class, 'show'])->name('admin.users.show');
    Route::get('/admin/users/destroy', [UserController::class, 'show'])->name('admin.users.destroy');

    Route::get('/admin/brokers', [BrokerController::class, 'index'])->name('admin.brokers.index');
    Route::get('/admin/brokers/create', [BrokerController::class, 'create'])->name('admin.brokers.create');
    Route::post('/admin/brokers/create', [BrokerController::class, 'store'])->name('admin.brokers.create');

    Route::get('/admin/brokers/edit/{id}', [BrokerController::class, 'edit'])->name('admin.brokers.edit');
    Route::post('/admin/brokers/edit/{id}', [BrokerController::class, 'update'])->name('admin.brokers.edit');

    Route::get('/admin/brokers/show', [BrokerController::class, 'show'])->name('admin.brokers.show');
    Route::get('/admin/brokers/destroy', [BrokerController::class, 'show'])->name('admin.brokers.destroy');

    Route::post('/admin/logout', [AuthenticatedSessionController::class, 'destroy'])->name('admin.logout');

    Route::post('/admin/update-wallet', [WalletController::class, 'updateWallet'])->name('admin.wallets.update-wallet');

    Route::resource('/admin/games', GameController::class);
    Route::resource('/admin/game-sessions', GameSessionController::class);
    Route::resource('/admin/transactions', TransactionController::class);
    Route::resource('/admin/biddings', BiddingController::class);

    Route::get('/admin/settings', [AdminDashboardController::class, 'settings'])->name('admin.settings');
    Route::post('/admin/settings', [AdminDashboardController::class, 'updateSettings'])->name('admin.settings.update');
});

// Broker routes
Route::middleware(['broker'])->group(function () {
    Route::get('/broker/dashboard', [BrokerDashboardController::class, 'index'])->name('broker.dashboard');
    Route::get('/broker/wallet', [BrokerDashboardController::class, 'wallet'])->name('broker.wallet');
    Route::get('/broker/withdraw-history', [BrokerDashboardController::class, 'withdrawhistory'])->name('broker.withdraw-history');

    Route::get('/broker/customers', [BrokerDashboardController::class, 'showCustomers'])->name('broker.showCustomers');
    Route::get('/broker/customers/create', [BrokerDashboardController::class, 'createCustomer'])->name('broker.customercreate');
    Route::post('/broker/customers/create', [BrokerDashboardController::class, 'storeCustomer'])->name('broker.customerstore');
    Route::get('/broker/customers/edit/{id}', [BrokerDashboardController::class, 'editCustomer'])->name('broker.editcustomer');
    Route::post('/broker/customers/edit/{id}', [BrokerDashboardController::class, 'updateCustomer'])->name('broker.updatecustomer');
    Route::post('/broker/customers/edit/{id}', [BrokerDashboardController::class, 'updateCustomer'])->name('broker.updatecustomer');
    Route::post('/broker/update-customer-wallet', [WalletController::class, 'updateWallet'])->name('broker.updatecustomerwallet');

    Route::get('/broker/withdrawal-history', [WithdrawalRequestController::class, 'showRequests'])->name('broker.showRequests');
    Route::post('/broker/withdraw-request', [WithdrawalRequestController::class, 'createWithdrawRequest'])->name('broker.requestWithdraw');
    Route::post('/broker/withdraw-request/approve/{id}', [WithdrawalRequestController::class, 'approve'])->name('broker.withdraw-request.approve');
    Route::post('/broker/withdraw-request/reject/{id}', [WithdrawalRequestController::class, 'reject'])->name('broker.withdraw-request.reject');

    // Other Broker Routes
});

// Customer routes
Route::middleware(['customer'])->group(function () {
    Route::get('/customer/dashboard', [CustomerDashboardController::class, 'index'])->name('customer.dashboard');
    Route::get('/customer/wallet', [CustomerDashboardController::class, 'wallet'])->name('customer.wallet');
    Route::get('/customer/withdraw-history', [CustomerDashboardController::class, 'withdrawhistory'])->name('customer.withdraw-history');
    Route::get('/customer/deposit-history', [CustomerDashboardController::class, 'deposithistory'])->name('customer.deposit-history');
    Route::get('/customer/bidding-history', [CustomerDashboardController::class, 'biddinghistory'])->name('customer.bidding-history');
    Route::get('/customer/active-bidding-history', [CustomerDashboardController::class, 'activebiddinghistory'])->name('customer.active-bidding-history');
    Route::get('/customer/profit-loss', [CustomerDashboardController::class, 'profitAndLoss'])->name('customer.profitloss');
    Route::post('/customer/reset-password', [CustomerDashboardController::class, 'resetPassword'])->name('customer.reset-password');
    Route::get('/customer/reset-password', [CustomerDashboardController::class, 'showResetPasswordForm'])->name('customer.show-reset-password-form');
    Route::get('/customer/all-transactions', [CustomerDashboardController::class, 'transactionHistory'])->name('customer.all-transactions');

    // Route::get('/customer/account', [CustomerDashboardController::class, 'account'])->name('customer.account');


    /* Ajax Paths */
    Route::get('/customer/activebiddinghistory', [CustomerDashboardController::class, 'activebiddinghistory'])->name('activebiddinghistory')->middleware('auth');
    Route::get('/customer/biddinghistory', [CustomerDashboardController::class, 'biddinghistory'])->name('biddinghistory')->middleware('auth');
    Route::get('/customer/deposithistory', [CustomerDashboardController::class, 'deposithistory'])->name('deposithistory')->middleware('auth');
    Route::get('/customer/withdrawhistory', [CustomerDashboardController::class, 'withdrawhistory'])->name('withdrawhistory')->middleware('auth');
    Route::get('/customer/transactions', [CustomerDashboardController::class, 'transactionHistory'])->name('transactions')->middleware('auth');;
    Route::get('/single', [BidController::class, 'show'])->name('bets.single');
    Route::get('/jodi', [BidController::class, 'jodishow'])->name('bets.jodi');
    // Route::post('/single', [BidController::class, 'show'])->name('bets.store');


    Route::post('/bets/store', [BidController::class, 'store'])->name('bets.store');

    // Other customer routes...
});

Route::get('/admin', [HomeController::class, 'adminRedirect']);
Route::get('/', [HomeController::class, 'index'])->name('/');
// Route::get('/single', [HomeController::class, 'single'])->name('single');
// Route::get('/jodi', [HomeController::class, 'jodi'])->name('jodi');
Route::get('/jodi-chart', [HomeController::class, 'jodi_chart'])->name('jodi-chart');
Route::get('/panel-chart', [HomeController::class, 'panel_chart'])->name('panel-chart');
Route::get('/games', [HomeController::class, 'allgames'])->name('all-games');
Route::get('/games/{game}', [HomeController::class, 'singlegame'])->name('singlegame');


Route::middleware('auth')->group(function () {
    Route::middleware('verified')->group(function () {
        // Route::get('/dashboard', [UserDashboardController::class, 'index'])->name('dashboardt');
    });
    Route::get('/profile', [ProfileController::class, 'edit'])->name('profile.edit');
    Route::patch('/profile', [ProfileController::class, 'update'])->name('profile.update');
    Route::delete('/profile', [ProfileController::class, 'destroy'])->name('profile.destroy');
});
